import java.awt.image.BufferedImage;

public class PixelBufferFilterAsBufferedImageFilter implements BufferedImageFilter {
	private PixelBufferFilter pixelBufferFilter;
	private int[] pixelBuffer;
	
	public PixelBufferFilterAsBufferedImageFilter(PixelBufferFilter pixelBufferFilter) {
		this.pixelBufferFilter = pixelBufferFilter;
		this.pixelBuffer = null;
	}
	
	public void filter(BufferedImage img) {
		int width = img.getWidth();
		int height = img.getHeight();
		int numPixels = width*height;
		
		// Ensure the size of the pixel buffer matches the number of pixels in the image
		if ((pixelBuffer == null) || (pixelBuffer.length != numPixels)) {
			pixelBuffer = new int[numPixels];
		}
		
		// Read the image's pixels into the pixel buffer
		img.getRGB(0, 0, width, height, pixelBuffer, 0, width);
		
		// Filter the contents of the pixel buffer
		pixelBufferFilter.filter(width, height, pixelBuffer);
		
		// Store the pixel buffer back into the original image
		img.setRGB(0, 0, width, height, pixelBuffer, 0, width);
	}
	
	public String toString() {
		return pixelBufferFilter.toString();
	}
}